@@ -15,6 +15,10 @@ def __createModuleFunctionView__(moduleName, functionName, is_main=False):
         # Creates the JSON config for the view modal form
         category = ht.getModuleCategory(moduleName)
         functionParams = Utils.getFunctionsParams(category=category, moduleName=moduleName, functionName=functionName)
+        
+        # Get posible functions with args that uses values from another func
+        funcsFromFunc = None if not hasattr( ht.getModule(moduleName), '_funcArgFromFunc_') else dict(ht.getModule(moduleName).funcArgFromFunc)
+
         moduleViewConfig = {}
 
         moduleViewConfig['__function__'] = functionName
@@ -49,6 +53,15 @@ def __createModuleFunctionView__(moduleName, functionName, is_main=False):
                     moduleViewConfig[param]['value'] = functionParams['defaults'][param]
                     if moduleViewConfig[param]['__type__'] == 'checkbox':
                         moduleViewConfig[param]['selected'] = moduleViewConfig[param]['value']
+            
+            # Create the data for auto fill the param with another funcs return
+            if funcsFromFunc and functionName in funcArgFromFunc and len(funcArgFromFunc[functionName]) > 0:
+                for arg in funcArgFromFunc[functionName]:
+                    if arg in moduleViewConfig:
+                        if not 'options_from_function' in moduleViewConfig[arg]:
+                            moduleViewConfig[arg]['options_from_function'] = {}
+                        for moduleToExecute in funcArgFromFunc[functionName][arg]:
+                            moduleViewConfig[arg]['options_from_function'][moduleToExecute] = funcArgFromFunc[functionName][arg][moduleToExecute]
         else:
             ht.Logger.printMessage(message='No function params', description=functionName, debug_core=True)
 
@@ -460,16 +473,27 @@ def __createHtmlModalForm__(mod, config_subkey='django_form_main_function', conf
                 if 'required' in temp_m_form[m] and temp_m_form[m]['required'] == True:
                     required = 'required'
                 
-                options_from_function = []
-                if 'options_from_function' in temp_m_form[m]:
-                    options_from_function = temp_m_form[m]['options_from_function']
-                    for optModuleName in options_from_function:
-                        if optModuleName in ht.getModulesNames():
-                            functionCall = 'ht.getModule(\'{mod}\').{func}()'.format(mod=optModuleName, func=temp_m_form[m]['options_from_function'][optModuleName])
-                            options_from_function = eval(functionCall)
-                        if 'core' == optModuleName:
-                            functionCall = 'ht.{func}()'.format(func=temp_m_form[m]['options_from_function'][optModuleName])
-                            options_from_function = eval(functionCall)
+                # Creates a select if any options are filled by another func
+                try:
+                    options_from_function = []
+                    if 'options_from_function' in temp_m_form[m]:
+                        options_from_function = temp_m_form[m]['options_from_function']
+                        for optModuleName in options_from_function:
+                            if optModuleName in ht.getModulesNames() or optModuleName in [ moduleNm.replace('ht_', '') for moduleNm in ht.getModulesNames() ]:
+                                functionCall = 'ht.getModule(\'{mod}\').{func}()'.format(mod=optModuleName, func=temp_m_form[m]['options_from_function'][optModuleName])
+                                options_from_function = eval(functionCall)
+                            elif 'core' == optModuleName:
+                                functionCall = 'ht.{func}()'.format(func=temp_m_form[m]['options_from_function'][optModuleName])
+                                options_from_function = eval(functionCall)
+                            else:
+                                functionCall = '{m}.{func}()'.format(m=optModuleName, func=temp_m_form[m]['options_from_function'][optModuleName])
+                                options_from_function = eval(functionCall)
+                except Exception as e:
+                    Logger.printMessage(str(e), is_error=True)
+                    options_from_function = []
+                
+                if options_from_function:
+                    input_type = 'select'
 
                 if input_type == 'file':
                     html += "<div class='input-group'>"
